@@ -1,16 +1,10 @@
-# Also, we can treat the process memory cache and the memcached differently by using different expirations.
-# For example, you may want process memory to expire quickly, but memcached to last a little longer since
-# you can actually keep it consistent across multiple machines. This example
-# forces Foo objects to be expired more aggressively from the local memory than memcached::
-
-
 from paver.defaults import Bunch
 
 options(
     setup=Bunch(
         name="stockpyle",
         packages=["stockpyle", "stockpyle.ext"],
-        version="0.0.8",
+        version="0.0.9",
         license="BSD",
         author="Matt Pizzimenti",
         author_email="mjpizz+stockpyle@gmail.com",
@@ -98,7 +92,7 @@ Manipulating batches of objects is also trivial::
     
     store.batch_put([f1, f2, f3])
     
-    o1, o2, o3 = store.batch_get([
+    o1, o2, o3 = store.batch_get(Foo, [
         {'key': 'my_key_1'},
         {'key': 'my_key_2'},
         {'key': 'my_key_3'},
@@ -110,7 +104,7 @@ Manipulating batches of objects is also trivial::
 
 Note: if you do a *batch_get* and one of the keys is null, it still gets returned as None::
     
-    o1, o2, o3 = store.batch_get([
+    o1, o2, o3 = store.batch_get(Foo, [
         {'key': 'my_key_1'},
         {'key': 'nonexistent_key'},
         {'key': 'my_key_3'},
@@ -132,7 +126,7 @@ ChainedStore takes an ordered list of stores and treats them as a write-through
 cache.  This example creates a write-through cache for SQLAlchemy-backed database objects::
 
     fast_cache = ProcessMemoryStore()
-    dist_cache = MemcacheStore(servers=["localhost:11711"])
+    dist_cache = MemcacheStore(servers=["localhost:11211"])
     persistent_store = SqlAlchemyStore(uri="sqlite:///data.sqlite")
     
     chained_store = ChainedStore([fast_cache, dist_cache, persistent_store])
@@ -176,8 +170,8 @@ Now, Foo is indexed by both 'key', *and* the combined attributes 'zap' and 'bar'
     
     store.put(f)
     
-    o1 = store.get({'key': 1})
-    o2 = store.get({'zap': 2, 'bar': 3})
+    o1 = store.get(Foo, {'key': 1})
+    o2 = store.get(Foo, {'zap': 2, 'bar': 3})
     
     assert(f == o1 == o2)
 
@@ -270,9 +264,26 @@ In order to enable MemcacheStore, you will need to install the python-memcached
 
 http://pypi.python.org/pypi/python-memcached
 
-The MemcacheStore supports polymorphic queries.  The native memcache API is used to support
+The MemcacheStore supports polymorphic storage and object expiration.  The native memcache API is used to support
 object expiration and batched operations.
 
+Shove Integration
+-----------------
+
+In order to enable ShoveStore, you will need to install the shove module:
+
+http://pypi.python.org/pypi/shove
+
+The Shove API provides a very broad array of storage backends with a dictionary-style interface,
+which work well in stockpyle. This example uses the shove backend for Amazon S3::
+    
+    from stockpyle.stores import ShoveStore
+    
+    s3_store = ShoveStore(shoveuri="s3://s3key:s3secret@your_s3_bucket_name")
+
+ShoveStores support polymorphic storage and object expiration.  Every object stored in the Shove is stored at
+a human-readable key, as a tuple of (obj, expiredate).
+
 SQLAlchemy Integration
 ----------------------
 
@@ -283,14 +294,14 @@ http://pypi.python.org/pypi/SQLAlchemy
 Typically, in SQLAlchemy you will use a session to store and retrieve your mapped objects::
 
     # create the object
-    obj = MyMappedObject()
+    obj = MyMappedObject(foobar=123)
     
     # store it
     session.save(obj)
     session.commit()
     
     # retrieve it
-    obj_retrieved = session.query(MyMappedObject).first()
+    obj_retrieved = session.query(MyMappedObject).filter(MyMappedObject.foobar == 123).first()
 
 You can do the same thing through a SqlAlchemyStore::
     
@@ -298,18 +309,18 @@ You can do the same thing through a SqlAlchemyStore::
     store = SqlAlchemyStore(uri="sqlite:///data.sqlite")
     
     # create the object
-    obj = MyMappedObject()
+    obj = MyMappedObject(foobar=123)
     
     # store it
     store.put(obj)
     
     # retrieve it
-    obj_retrieved = store.get(MyMappedObject, {'id': obj.id})
+    obj_retrieved = store.get(MyMappedObject, {'foobar': 123})
 
 Now you can put this SqlAlchemyStore in a ChainedStore for write-through caching::
     
     # use MemcacheStore as a cache layer
-    mc = MemcacheStore()
+    mc = MemcacheStore(servers=["localhost:11211"])
     sa = SqlAlchemyStore(uri="sqlite:///data.sqlite")
     store = ChainedStore([mc, sa])
     
@@ -331,7 +342,7 @@ StockpyleSessionExtension to your session object::
     from stockpyle.stores import MemcacheStore
     from stockpyle.ext.sqlalchemy import StockpyleSessionExtension
 
-    mc = MemcacheStore(servers=["localhost:11711"])
+    mc = MemcacheStore(servers=["localhost:11211"])
     ext = StockpyleSessionExtension(store=mc)
     my_session = sessionmaker(extension=ext)
 
@@ -340,7 +351,7 @@ it will also perform the corresponding puts and deletes in the MemcacheStore.
 
 Objects that you get from SqlAlchemyStore are bound to the internal session
 object on that store.  Keep this in mind when you are using your own session,
-since you will have to *merge()* stockpyle-retrieved object into your session::
+since you will have to *merge()* the stockpyle-retrieved object into your session::
     
     # get an object from SqlAlchemyStore
     obj = sa_store.get(MyMappedObject, {'id': 'foobar123'})
@@ -348,29 +359,13 @@ since you will have to *merge()* stockpyle-retrieved object into your session::
     # change some information
     obj.name = "bleh"
     
-    # you must merge the object into my_session
-    # before you can commit it with SQLAlchemy
+    # if you want to use this object in your SQLAlchemy
+    # session, you must merge the object first since the
+    # object is currently bound to the internal session
+    # inside the SqlAlchemyStore
     my_session.merge(obj)
     my_session.commit()
 
-Shove Integration
------------------
-
-In order to enable ShoveStore, you will need to install the shove module:
-
-http://pypi.python.org/pypi/shove
-
-The stockpyle API works well with any dictionary-style storage.  The Shove library provides
-a very broad array of storage backends with a dictionary-style interface.  You can create
-a ShoveStore easily in stockpyle::
-    
-    from stockpyle.stores import ShoveStore
-    
-    s3_store = ShoveStore(shoveuri="s3://s3key:s3secret@whatever_bucket_name_you_want")
-
-ShoveStores support polymorphic storage and object expiration.  Every object stored in the Shove is stored at
-human-readable key as a tuple (obj, expiredate).
-
 Defining a custom Store
 -----------------------
 Although stockpile contains most of the stores you will need to support
