@@ -1,9 +1,6 @@
-import threading
 from datetime import datetime, timedelta
 from stockpyle._helpers import KeyValueHelper
 
-_threadlocal = threading.local()
-
     
 class BaseStore(object):
     """represents a standard storage container"""
