@@ -1,4 +1,4 @@
-from stockpyle._base import BaseStore
+from stockpyle._base import BaseStore, BaseDictionaryStore
 from stockpyle._procmem import ProcessMemoryStore
 from stockpyle._memcache import MemcacheStore
 from stockpyle._shove import ShoveStore
