@@ -44,6 +44,4 @@ if __name__ == "__main__":
     sys.path.insert(0, os.path.join(os.path.dirname(__file__), ".."))
 
     # run nosetests
-    sys.argv = sys.argv + FLAGS
-    nose.core.TestProgram(defaultTest="tests", argv=sys.argv)
-
+    nose.core.TestProgram(defaultTest="tests", argv=sys.argv+FLAGS)
\ No newline at end of file
