@@ -19,7 +19,9 @@ class ProcessMemoryStoreTestCase(TestCase):
         dummyobj = Foo()
         
         self.assertRaises(NotImplementedError, lambda: ms.put(dummyobj))
+        self.assertRaises(NotImplementedError, lambda: ms.batch_put([dummyobj]))
         self.assertRaises(NotImplementedError, lambda: ms.delete(dummyobj))
+        self.assertRaises(NotImplementedError, lambda: ms.batch_delete([dummyobj]))
         self.assertRaises(NotImplementedError, lambda: ms.get(Foo, {}))
         self.assertRaises(NotImplementedError, lambda: ms.batch_get(Foo, [{}, {}]))
     
\ No newline at end of file
