@@ -44,18 +44,31 @@ if __HAVE_SA:
         store = property(lambda self: self.__store)
     
         def setUp(self):
-            self.__store = SqlAlchemyStore(uri="sqlite:///:memory:")
-            DeclarativeBase.metadata.create_all(bind=self.__store.engine)
+            self.__engine = create_engine("sqlite:///:memory:")
+            self.__store = SqlAlchemyStore(engine=self.__engine)
+            DeclarativeBase.metadata.create_all(bind=self.__engine)
         
         def tearDown(self):
-            DeclarativeBase.metadata.drop_all(bind=self.__store.engine)
+            DeclarativeBase.metadata.drop_all(bind=self.__engine)
         
         def test_instantiation_with_session_generates_deprecation_warning(self):
-            session = sessionmaker(autoflush=True, bind=self.__store.engine)()
+            session = sessionmaker(autoflush=True, bind=self.__engine)()
             self.assertRaises(DeprecationWarning, lambda: SqlAlchemyStore(session=session))
         
-        def test_instantiation_with_nothing_raises_error(self):
-            self.assertRaises(ValueError, lambda: SqlAlchemyStore())
+        def test_instantiation_with_uri_works(self):
+            store = SqlAlchemyStore(uri="sqlite:///:memory:")
+        
+        def test_instantiation_with_nothing_is_okay_and_requires_objects_to_be_bound_to_engine(self):
+            # create an engine-unbound SqlAlchemyStore
+            store = SqlAlchemyStore()
+            obj = Foobar(1,2,3)
+            self.assertRaises(Exception, lambda: store.put(obj))
+            DeclarativeBase.metadata.bind = self.__engine
+            try:
+                # now we should be able to put the object
+                store.put(obj)
+            finally:
+                DeclarativeBase.metadata.bind = None
         
         def test_instantiation_with_connstring_and_engine_raises_error(self):
             engine = create_engine("sqlite:///:memory:")
@@ -85,7 +98,7 @@ if __HAVE_SA:
             self.store.put(obj)
             
             # create an external session
-            session = sessionmaker(autoflush=True, bind=self.__store.engine)()
+            session = sessionmaker(autoflush=True, bind=self.__engine)()
             
             # change the object, we're going to save it to SA directly
             obj.foo = 999
@@ -108,7 +121,7 @@ if __HAVE_SA:
             self.store.put(obj)
         
             # get using a sqlalchemy session
-            session = sessionmaker(autoflush=True, bind=self.__store.engine)()
+            session = sessionmaker(autoflush=True, bind=self.__engine)()
             obj_r = session.query(Foobar).first()
             self.assertEqual(obj_r, obj)
         
@@ -132,7 +145,7 @@ if __HAVE_SA:
             self.store.put(obj2)
         
             # get using a sqlalchemy session
-            session = sessionmaker(autoflush=True, bind=self.__store.engine)()
+            session = sessionmaker(autoflush=True, bind=self.__engine)()
             objs = session.query(Foobar).all()
             self.assertEqual(len(objs), 2)
         
@@ -160,7 +173,7 @@ if __HAVE_SA:
             self.store.put(obj)
         
             # get using a sqlalchemy session
-            session = sessionmaker(autoflush=True, bind=self.__store.engine)()
+            session = sessionmaker(autoflush=True, bind=self.__engine)()
             obj_r = session.query(Foobar).first()
             self.assertEqual(obj_r, obj)
         
@@ -181,7 +194,7 @@ if __HAVE_SA:
             self.store.put(obj)
         
             # get using a sqlalchemy session
-            session = sessionmaker(autoflush=True, bind=self.__store.engine)()
+            session = sessionmaker(autoflush=True, bind=self.__engine)()
             obj_r = session.query(Foobar).first()
             self.assertEqual(obj_r, obj)
         
@@ -201,17 +214,18 @@ if __HAVE_SA:
     
         def setUp(self):
             self.__lm = CountingStoreWrapper(ProcessMemoryStore())
-            self.__sa = CountingStoreWrapper(SqlAlchemyStore(uri="sqlite:///:memory:"))
+            self.__engine = create_engine("sqlite:///:memory:")
+            self.__sa = CountingStoreWrapper(SqlAlchemyStore(engine=self.__engine))
             self.__store = ChainedStore([self.__lm, self.__sa])
             
             # create a special synchronizing session
             ext = StockpyleSessionExtension(self.__lm)
-            self.__session = sessionmaker(autoflush=True, extension=ext, bind=self.__sa.engine)()
+            self.__session = sessionmaker(autoflush=True, extension=ext, bind=self.__engine)()
             
-            DeclarativeBase.metadata.create_all(bind=self.__sa.engine)
+            DeclarativeBase.metadata.create_all(bind=self.__engine)
 
         def tearDown(self):
-            DeclarativeBase.metadata.drop_all(bind=self.__sa.engine)
+            DeclarativeBase.metadata.drop_all(bind=self.__engine)
     
         def test_local_memory_updated_even_when_object_updated_outside_stockpyle(self):
         
